@@ -190,7 +190,7 @@ def _prepare_asset_details_params(**options):
     """
     return only(options, "exif", "faces", "colors", "image_metadata", "media_metadata", "cinemagraph_analysis",
                 "pages", "phash", "coordinates", "max_results", "quality_analysis", "derived_next_cursor",
-                "accessibility_analysis", "versions")
+                "accessibility_analysis", "versions", "related", "related_next_cursor")
 
 
 def update(public_id, **options):
@@ -295,6 +295,50 @@ def delete_derived_by_transformation(public_ids, transformations,
     return call_api("delete", uri, params, **options)
 
 
+def add_related_assets(public_id, assets_to_relate, resource_type="image", type="upload", **options):
+    """
+    Relates an asset to other assets by public IDs.
+
+    :param public_id: The public ID of the asset to update.
+    :type public_id: str
+    :param assets_to_relate: The array of up to 10 fully_qualified_public_ids given as resource_type/type/public_id.
+    :type assets_to_relate: list[str]
+    :param type: The upload type. Defaults to "upload".
+    :type type: str
+    :param resource_type: The type of the resource. Defaults to "image".
+    :type resource_type: str
+    :param options: Additional options.
+    :type options: dict, optional
+    :return: The result of the command.
+    :rtype: dict
+    """
+    uri = ["resources", "related_assets", resource_type, type, public_id]
+    params = {"assets_to_relate": utils.build_array(assets_to_relate)}
+    return call_json_api("post", uri, params, **options)
+
+
+def delete_related_assets(public_id, assets_to_unrelate, resource_type="image", type="upload", **options):
+    """
+    Unrelates an asset from other assets by public IDs.
+
+    :param public_id: The public ID of the asset to update.
+    :type public_id: str
+    :param assets_to_unrelate: The array of up to 10 fully_qualified_public_ids given as resource_type/type/public_id.
+    :type assets_to_unrelate: list[str]
+    :param type: The upload type.
+    :type type: str
+    :param resource_type: The type of the resource: defaults to "image".
+    :type resource_type: str
+    :param options: Additional options.
+    :type options: dict, optional
+    :return: The result of the command.
+    :rtype: dict
+    """
+    uri = ["resources", "related_assets", resource_type, type, public_id]
+    params = {"assets_to_unrelate": utils.build_array(assets_to_unrelate)}
+    return call_json_api("delete", uri, params, **options)
+
+
 def tags(**options):
     resource_type = options.pop("resource_type", "image")
     uri = ["tags", resource_type]
