@@ -459,6 +459,13 @@ P9/AFGGFyjOXZtQAAAAAElFTkSuQmCC\
             "public_ids": public_ids,
         })
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test_clear_invalid(self, mocker):
+        mocker.return_value = MOCK_RESPONSE
+        uploader.update_metadata(METADATA_FIELDS, public_ids=[TEST_ID], clear_invalid=True)
+        self.assertTrue(get_param(mocker, "clear_invalid"))
+
     def test_upload_with_metadata(self):
         """Upload should support `metadata` parameter"""
         result = uploader.upload(TEST_IMAGE, tags=[UNIQUE_TAG], metadata=METADATA_FIELDS)
@@ -799,6 +806,36 @@ P9/AFGGFyjOXZtQAAAAAElFTkSuQmCC\
         self.assertIsNone(get_param(mocker, "signature"))
         self.assertEqual(get_param(mocker, "upload_preset"), API_TEST_PRESET)
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test_upload_preset_in_config(self, mocker):
+        """Should support uploading using presets from config"""
+        mocker.return_value = MOCK_RESPONSE
+        cloudinary.config().upload_preset = API_TEST_PRESET
+        uploader.upload(TEST_IMAGE)
+
+        args, kargs = mocker.call_args
+
+        self.assertTrue(get_uri(args).endswith("/image/upload"))
+        self.assertEqual("POST", get_method(mocker))
+        self.assertIsNotNone(get_param(mocker, "file"))
+        self.assertEqual(get_param(mocker, "upload_preset"), API_TEST_PRESET)
+
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test1_upload_preset_in_config(self, mocker):
+        """Should support overwriting upload presets in config"""
+        mocker.return_value = MOCK_RESPONSE
+        cloudinary.config().upload_preset = API_TEST_PRESET
+        uploader.upload(TEST_IMAGE, upload_preset=None)
+
+        args, kargs = mocker.call_args
+
+        self.assertTrue(get_uri(args).endswith("/image/upload"))
+        self.assertEqual("POST", get_method(mocker))
+        self.assertIsNotNone(get_param(mocker, "file"))
+        self.assertEqual(get_param(mocker, "upload_preset"), None)
+
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test_background_removal(self):
         """Should support requesting background_removal """
@@ -892,34 +929,23 @@ P9/AFGGFyjOXZtQAAAAAElFTkSuQmCC\
                 uploader.upload(TEST_IMAGE, access_control=invalid_value)
 
     @patch('urllib3.request.RequestMethods.request')
-    def test_cinemagraph_analysis(self, request_mock):
-        """Should support cinemagraph analysis in upload and explicit"""
+    def test_various_upload_parameters(self, request_mock):
+        """Should support various parameters in upload and explicit"""
         request_mock.return_value = MOCK_RESPONSE
 
-        uploader.upload(TEST_IMAGE, cinemagraph_analysis=True)
+        options = {'cinemagraph_analysis': True, 'accessibility_analysis':True, 'media_metadata':True}
+        uploader.upload(TEST_IMAGE, **options)
 
         params = get_params(request_mock.call_args[0])
-        self.assertIn("cinemagraph_analysis", params)
+        for param in options.keys():
+            self.assertIn(param, params)
 
-        uploader.explicit(TEST_IMAGE, cinemagraph_analysis=True)
+        uploader.explicit(TEST_IMAGE, **options)
 
         params = get_params(request_mock.call_args[0])
-        self.assertIn("cinemagraph_analysis", params)
+        for param in options.keys():
+            self.assertIn(param, params)
 
-    @patch('urllib3.request.RequestMethods.request')
-    def test_accessibility_analysis(self, request_mock):
-        """Should support accessibility analysis in upload and explicit"""
-        request_mock.return_value = MOCK_RESPONSE
-
-        uploader.upload(TEST_IMAGE, accessibility_analysis=True)
-
-        params = get_params(request_mock.call_args[0])
-        self.assertIn("accessibility_analysis", params)
-
-        uploader.explicit(TEST_IMAGE, accessibility_analysis=True)
-
-        params = get_params(request_mock.call_args[0])
-        self.assertIn("accessibility_analysis", params)
 
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test_eval_upload_parameter(self):
